# edabox
Gain Insight into Datasets

---
### Installation
- [PyPI Link](https://pypi.org/project/edabox/1.0.0/)
  > ```pip install edabox==1.0.0```
- [TestPyPI Link](https://test.pypi.org/project/edabox/1.0.0/)
  > ```pip install -i https://test.pypi.org/simple/ edabox==1.0.0```

---  
